+++
title = "Special Block with just white space"
description = """
  This post contains an Org Special Block with just white space (blank
  line).
  """
tags = ["special-block", "whitespace"]
draft = false
+++

<div class="foo">
  <div></div>



</div>
